@@ -25,13 +25,6 @@
 
 yupana <- function(dependencies = FALSE) {
   
-  message("
-  - If is the first time running Yupana consider install the app dependencies:
-  > inti::yupana(dependencies = TRUE)
-  - Demo:
-  > https://inkaverse.com/articles/apps
-          ")
-  
   if (dependencies == TRUE) {
     
     source("https://raw.githubusercontent.com/Flavjack/inti/master/inst/yupana/setup.R")
